@@ -9,19 +9,23 @@
                         containing data.
 """
 
-from typing import Dict, List, NamedTuple
+from dataclasses import dataclass
+from typing import Dict, List, Sequence
 
 import pydicom
 import SimpleITK as sitk
 
 
-class SegmentationDataModel(NamedTuple):
+@dataclass
+class SegmentationDataModel:
     """
     A named tuple grouping the segmentation as several binary label maps (one for each organ in the segmentation) and
     the segmentation as a simpleITK image.
 
     Elements
     --------
+    modality : str
+        Segmentation modality (ex: SEG, RTSTRUCT).
     simple_itk_label_maps : Dict[str, sitk.Image]
         A dictionary that contains the name of the organs and their corresponding binary label map as a simpleITK
         image. Keys are organ names and values are binary label maps. Thus, the label maps dictionary is formatted
@@ -33,12 +37,15 @@ class SegmentationDataModel(NamedTuple):
                 ...
             }
     """
+    modality: str = None
     simple_itk_label_maps: Dict[str, sitk.Image] = None
 
 
-class ImageDataModel(NamedTuple):
+@dataclass
+class ImageDataModel:
     """
-    A named tuple grouping the patient's dicom header and its medical image as a simpleITK image.
+    A named tuple grouping the patient's dicom header, its medical image as a simpleITK image and a sequence of the
+    paths to each dicom contained in the series.
 
     Elements
     --------
@@ -46,12 +53,16 @@ class ImageDataModel(NamedTuple):
         Dicom header dataset.
     simple_itk_image : Image
         Segmentation as a SimpleITK image.
+    paths_to_dicoms : Sequence[str]
+        A list of the paths to each dicom contained in the series.
     """
     dicom_header: pydicom.dataset.FileDataset
     simple_itk_image: sitk.Image
+    paths_to_dicoms: Sequence[str]
 
 
-class ImageAndSegmentationDataModel(NamedTuple):
+@dataclass
+class ImageAndSegmentationDataModel:
     """
     A named tuple grouping the patient data retrieved from his dicom files and the segmentation data retrieved from
     the segmentation file.
@@ -60,21 +71,22 @@ class ImageAndSegmentationDataModel(NamedTuple):
     --------
     image : ImageDataModel
         The patient's medical image data.
-    segmentation : SegmentationDataModel
+    segmentation : Sequence[SegmentationDataModel]
         Data from the segmentation of the patient's medical image.
     """
     image: ImageDataModel
-    segmentation: SegmentationDataModel = None
+    segmentations: Sequence[SegmentationDataModel] = None
 
 
-class PatientDataModel(NamedTuple):
+@dataclass
+class PatientDataModel:
     """
     A named tuple grouping the patient's data extracted from its dicom files and the patient's medical image
     segmentation data extracted from the segmentation files, for each available modality. The patient data model is
     formatted as follows :
 
         PatientDataModel = (
-            "patient_name": str,
+            "patient_id": str,
             "data": [
                 ImageAndSegmentationDataModel,
                 ImageAndSegmentationDataModel
@@ -82,5 +94,5 @@ class PatientDataModel(NamedTuple):
             ]
         )
     """
-    patient_name: str
+    patient_id: str
     data: List[ImageAndSegmentationDataModel]
