@@ -24,7 +24,7 @@ if __name__ == "__main__":
         path_to_database="data/patients_database.h5",
     )
 
-    patients_who_failed = database.create_database(
+    patients_who_failed = database.create(
         path_to_patients_folder="data/Patients",
         tags_to_use_as_attributes=[(0x0008, 0x103E), (0x0020, 0x000E), (0x0008, 0x0060)],
         series_descriptions="data/series_descriptions.json",
